Flask-JSGlue
============

[![Build Status](https://travis-ci.org/stewartpark/Flask-JSGlue.svg)](https://travis-ci.org/stewartpark/Flask-JSGlue)

Flask-JSGlue helps hook up your Flask application nicely with the front end.


Tested on Python 2.7, 3.3, 3.4, 3.5, 3.6, and PyPy2/3.

Homepage: http://stewartpark.github.io/Flask-JSGlue/
